<?php

namespace Linear\Templates;

function realtor( $listing = null ) {

    if( !$listing ){
        return '';
    }

    $realtor = $listing['realtor'];

    if ( !$realtor ) {
        return '';
    }

    $use_realtor_data = false;
    if( isset( $listing['contactInfoSource'] ) && $listing['contactInfoSource'] === 'REALTOR' ){
        $use_realtor_data = true;
    }

    $options = get_option( 'linear_settings' );
    $contact_method = 'custom_url';
    if( isset( $options['contact_method'] ) ){
        $contact_method = $options['contact_method'];
    }

    $contact_api_url = '';
    if( isset( $options['contact_api_url'] ) ){
        $contact_api_url = $options['contact_api_url'];
    }

    // Custom URL contact link
    $contact_link = '';
    if( $contact_method === 'custom_url' ){
        if( esc_html( get_linear_option_value('contact_url') ) ){
            $contact_link = esc_html( get_linear_option_value('contact_url') );
    
            $contact_link_query = parse_url( esc_html( get_linear_option_value('contact_url') ), PHP_URL_QUERY );
    
            $additive_listing_id = 'listing_id=' . $listing['id'];
            $additive_listing_short_id = 'short_id=' . $listing['identifier'];
            $additive_listing_address = 'listing_address=' . urlencode( $listing['address'] );
            $additive_listing_realtor_name = 'realtor_name=' . urlencode( $listing['realtor']['name'] );
            $additive_listing_realtor_email = 'realtor_email=' . urlencode( $listing['realtor']['email'] );
            $additive_listing_realtor_company = 'realtor_company=' . urlencode( $listing['realtor']['companyName'] );
            $additive_listing_realtor_company_email = 'realtor_company_email=' . urlencode( $listing['realtor']['companyEmail'] );
    
            if( $contact_link_query ){
                $contact_link .= '&';
            } else {
                $contact_link .= '?';
            }
    
            $contact_link .= $additive_listing_id . 
            '&' . strtolower( $additive_listing_short_id ) .
            '&' . strtolower( $additive_listing_address ) .
            '&' . strtolower( $additive_listing_realtor_name ) .
            '&' . strtolower( $additive_listing_realtor_email ) .
            '&' . strtolower( $additive_listing_realtor_company ) .
            '&' . strtolower( $additive_listing_realtor_company_email );
    
        } else if( get_object_value( $listing, 'integrationDixuEnabled' ) ) {
            $contact_link = esc_html( get_listing_link( $listing, 'dixu_listing_url' ) );
        }
    }

    ob_start(); ?>

        <?php if (
            ( 
                $contact_method === 'form' &&
                $contact_api_url === ''
            ) ||
            ( $contact_method === 'custom_url' )
        ) {
            
            /**
             * Legacy code
             */
            ?>

            <div class="linear-o-row">
                <div class="linear-o-col-12">
                    <div class="linear-c-card">
                        <div class="linear-o-row linear-u-items-center linear-u-text-center linear-u-text-left@md" style="display: flex; justify-content: space-between">

                            <?php if( $use_realtor_data && isset( $realtor['avatar'] ) && $realtor['avatar'] ){ ?>
                                <div class="linear-o-col-5 linear-o-col-2@md linear-o-col-1@xl linear-u-mx-auto">
                                    <img src="<?php echo $realtor['avatar']; ?>" class="linear-c-avatar--agent linear-u-mb-2 linear-u-mb-0@md linear-u-ml-0@md linear-u-mx-auto" />
                                </div>
                            <?php } ?>

                            <div class="linear-o-col-7@md linear-o-col-9@xl">
                                <p class="linear-c-card__heading linear-c-card__heading--sm linear-u-mb-0.5">

                                    <?php
                                        if( isset( $listing['rawDataForFiltering']['productGroup'] ) ){

                                            $type = _x('apartment', 'type name in realtor-block', 'linear');

                                            $data_types = [
                                                [
                                                    'value' => 'APARTMENTS',
                                                    'string' => _x('apartment', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'FARMS',
                                                    'string' => _x('farm', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'PLOTS',
                                                    'string' => _x('plot', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'GARAGES',
                                                    'string' => _x('garage', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'NEWLY_CONSTRUCTED',
                                                    'string' => _x('new building', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'VACATION_APARTMENT',
                                                    'string' => _x('vacation apartment', 'type name in realtor-block', 'linear')
                                                ],
                                                [
                                                    'value' => 'BUSINESS_PREMISES',
                                                    'string' => _x('business premise', 'type name in realtor-block', 'linear')
                                                ]
                                            ];

                                            foreach( $data_types as $data_type ){
                                                if( $data_type['value'] === $listing['rawDataForFiltering']['productGroup'] ){
                                                    $type = $data_type['string'];
                                                }
                                            }

                                            if( comparator_is_sub_value( $listing, ['rawDataForFiltering', 'commissionType'], 'SELL') ){
                                                echo esc_html( sprintf( __('This %s is sold by', 'linear'), $type ) );
                                            } else {
                                                echo esc_html( sprintf( __('This %s is rented by', 'linear'), $type ) );
                                            }

                                            if( $use_realtor_data ){
                                                echo esc_html(
                                                    sprintf(
                                                        ' %s%s',
                                                        $realtor['name'],
                                                        isset( $realtor['jobTitle'] ) && $realtor['jobTitle'] ? ', ' . $realtor['jobTitle'] : ''
                                                    )
                                                );
                                            } else {
                                                echo esc_html(
                                                    sprintf(
                                                        ' %s',
                                                        $realtor['companyName']
                                                    )
                                                );
                                            }
                                        }
                                    ?>
                                </p>

                                <?php if( $use_realtor_data ){
                                    if( !comparator_is_sub_value( $listing, ['realtor', 'companyName'], null) ){ ?>
                                        <p class="linear-u-mb-0.5"><?php echo $realtor['companyName']; ?></p>
                                        <a class="linear-c-card__heading__phone" href="tel:<?php echo $listing['realtor']['tel']?>">
                                            <span class="linear-c-card__heading__icon"><?php echo icon( 'phone' ); ?></span>
                                            <span class="linear-c-card__heading__number"><?php echo $listing['realtor']['tel']?></span>
                                        </a>
                                        <a class="linear-c-card__heading__email" href="mailto:<?php echo $listing['realtor']['email']?>">
                                            <span class="linear-c-card__heading__icon"><?php echo icon( 'envelope' ); ?></span>
                                            <span class="linear-c-card__heading__text"><?php echo $listing['realtor']['email']?></span>
                                        </a>
                                    <?php }
                                } else {
                                    if( !comparator_is_sub_value( $listing, ['realtor', 'companyEmail'], null) ){ ?>
                                        <a class="linear-c-card__heading__phone" href="tel:<?php echo $listing['realtor']['companyTel']?>">
                                            <span class="linear-c-card__heading__icon"><?php echo icon( 'phone' ); ?></span>
                                            <span class="linear-c-card__heading__number"><?php echo $listing['realtor']['companyTel']?></span>
                                        </a>
                                        <a class="linear-c-card__heading__email" href="mailto:<?php echo $listing['realtor']['companyEmail']?>">
                                            <span class="linear-c-card__heading__icon"><?php echo icon( 'envelope' ); ?></span>
                                            <span class="linear-c-card__heading__text"><?php echo $listing['realtor']['companyEmail']?></span>
                                        </a>
                                    <?php }
                                } ?>
    
                            </div>
    
    
                            <div class="linear-o-col-3@md linear-o-col-2@xl linear-u-text-right@md mobile-margin-top">
                                <?php if ( get_constant( $listing, 'status') === 'LIGHT_MIGRATED' || get_linear_option_value('contact_url') !== null && $contact_link ) { ?>
                                    <a 
                                        href="<?php echo $contact_link; ?>" 
                                        target="_blank" 
                                        class="linear-c-button linear-c-button--outline linear-c-button--primary linear-c-button--full"
                                    ><?php
                                        esc_attr_e( 'Contact', 'linear' );
                                    ?></a>
                                <?php } ?>

                                <div class="linear-u-mt-0.5 linear-c-logo--company">
                                    <img src="<?php echo get_company_logo( $realtor ); ?>" class="linear-c-logo linear-c-avatar--company__content linear-u-mx-auto linear-u-ml-0@md">
                                </div>
                            </div>
                        </div>

                        <?php
                            do_action('linear_listing_realtor', $listing);
                            do_action('linear_realtor', $listing);
                        ?>

                    </div>
                </div>
            </div>

        <?php } else if( $contact_method === 'form' ) {
        
            /**
             * Realtor data with form
             */
        
        ?>
            <div class="linear-o-row">
                <div class="linear-o-col-12">
                    <div class="linear-c-card">
                        <div class="linear-section-realtor">

                            <div class="linear-section-realtor__info-wrapper">
                                <?php if( $use_realtor_data ){ ?>

                                    <div>
                                        <h4><?php echo __('Contact', 'linear'); ?></h4>
                                        
                                        <div class="linear-section-realtor__person">
                                        
                                            <div class="linear-section-realtor__person__image" style="background-image: url('<?php echo $listing['realtor']['avatar'] ? $listing['realtor']['avatar'] : $listing['realtor']['companyLogo'] ?>');"></div>

                                            <div class="linear-section-realtor__person__info">

                                                <?php if( $listing['realtor']['name'] ){ ?>
                                                    <p class="linear-section-realtor__person__name"><?php echo $listing['realtor']['name']; ?></p>
                                                <?php } ?>

                                                <?php if( $listing['realtor']['jobTitle'] ){ ?>
                                                    <p class="linear-section-realtor__person__title"><?php echo $listing['realtor']['jobTitle']; ?></p>
                                                <?php } ?>

                                                <?php if( urlencode( $listing['realtor']['email'] ) ){ ?>
                                                    <a class="linear-section-realtor__person__email" href="mailto:<?php echo $listing['realtor']['email']; ?>"><?php echo $listing['realtor']['email']; ?></a>
                                                <?php } ?>

                                                <?php if( $listing['realtor']['tel'] ){ ?>
                                                    <a class="linear-section-realtor__person__phone" href="tel:<?php echo str_replace(' ', '', $listing['realtor']['tel']); ?>"><?php echo $listing['realtor']['tel']; ?></a>
                                                <?php } ?>

                                            </div>
                                        </div>

                                    </div>

                                <?php } else { ?>

                                    <div>
                                        <h4><?php echo __('Contact', 'linear'); ?></h4>

                                        <div class="linear-section-realtor__company">

                                            <div class="linear-section-realtor__company__image" style="background-image: url('<?php echo $listing['realtor']['companyLogo']; ?>');"></div>
                                                <div class="linear-section-realtor__company__info">

                                                    <?php if( $listing['realtor']['companyName'] ){ ?>
                                                        <p class="linear-section-realtor__company__name"><?php echo $listing['realtor']['companyName']; ?></p>
                                                    <?php } ?>

                                                    <?php if( urlencode( $listing['realtor']['companyEmail'] ) ){ ?>
                                                        <a class="linear-section-realtor__company__email" href="mailto:<?php echo urlencode( $listing['realtor']['companyEmail'] ); ?>"><?php echo urlencode( $listing['realtor']['companyEmail'] ); ?></a>
                                                    <?php } ?>

                                                    <?php if( $listing['realtor']['companyTel'] ){ ?>
                                                        <a class="linear-section-realtor__company__phone" href="tel:<?php echo str_replace(' ', '', $listing['realtor']['companyTel']); ?>"><?php echo $listing['realtor']['companyTel']; ?></a>
                                                    <?php } ?>

                                                </div>
                                            </div>

                                        </div>

                                    </div>


                                <?php } ?>

                                <?php /* if( $contact_method === 'custom_url' && ( get_constant( $listing, 'status') === 'LIGHT_MIGRATED' || get_linear_option_value('contact_url') !== null && $contact_link ) ){ ?>
                                    <div class="linear-section-realtor__contact-url">
                                        <a href="<?php echo $contact_link ?>"><?php echo __('Contact us', 'linear') ?></a>
                                        <div class="linear-section-realtor__contact-url__logo" style="background-image: url('<?php echo get_company_logo( $realtor ); ?>');">
                                        </div>
                                    </div>
                                <?php } */ ?>
                            </div>

                            <?php if( $contact_method === 'form' ){ ?>
                                <form class="linear-section-realtor__form" id="linear-single-listing-contact-form">

                                    <div class="linear-section-realtor__columns">
                                        <div class="linear-section-realtor__column">
                                            <fieldset>
                                                <legend class="linear-section-realtor__form__label"><?php echo __('Reason for contact?', 'linear') ?></legend>
                                                <div>
                                                    <div class="linear-section-realtor__form__field">
                                                        <input class="linear-section-realtor__form__field__checkbox" id="info" type="checkbox" name="more_info">
                                                        <label for="info"><?php echo __('I need more information about the listing', 'linear') ?></label>
                                                    </div>
                                                    <br>
                                                    <div class="linear-section-realtor__form__field">
                                                        <input class="linear-section-realtor__form__field__checkbox" id="see" type="checkbox" name="want_to_see">
                                                        <label for="see"><?php echo __('I would like to see the listing', 'linear') ?></label>
                                                    </div>
                                                    
                                                    <?php if( comparator_is_sub_value( $listing, ['rawDataForFiltering', 'commissionType'], 'SELL') ){ ?>
                                                        <br>
                                                        <div class="linear-section-realtor__form__field">
                                                            <input class="linear-section-realtor__form__field__checkbox" id="buy" type="checkbox" name="want_to_buy">
                                                            <label for="buy"><?php echo __('I would like to make an offer', 'linear') ?></label>
                                                        </div>
                                                    <?php } ?>
                                                </div>
                                            </fieldset>
                                        </div>

                                        <div class="linear-section-realtor__column">

                                            <fieldset>
                                                <legend class="linear-section-realtor__form__label"><?php echo __('Contact information', 'linear') ?></legend>
                                                <input required class="linear-section-realtor__form__field__text" type="text" id="name" name="name" required minlength="3" maxlength="50" placeholder="<?php _e('Name', 'linear') ?>"><label for="name"><?php _e('Name', 'linear') ?></label>

                                                <input required class="linear-section-realtor__form__field__text" type="email" id="email" name="email" required minlength="4" maxlength="50" placeholder="<?php _e('Email', 'linear') ?>"><label for="name"><?php _e('Email', 'linear') ?></label>

                                                <input required class="linear-section-realtor__form__field__text" type="text" id="phone" name="phone" required minlength="5" maxlength="15" placeholder="<?php _e('Phone', 'linear') ?>"><label for="name"><?php _e('Phone', 'linear') ?></label>
                                            </fieldset>

                                        </div>

                                        <div class="linear-section-realtor__column">
                                            <fieldset>
                                                <legend class="linear-section-realtor__form__label"><?php echo __('Message', 'linear') ?></legend>
                                                <textarea class="linear-section-realtor__form__field__textarea" name="message" id="" cols="30" rows="5" placeholder="<?php _e('Your message', 'linear') ?>"></textarea>
                                            </fieldset>
                                        </div>
                                    </div>

                                    <button class="linear-section-realtor__form__submit" type="submit">
                                        <?php echo icon('arrow-top-right');?>
                                        <span class="linear-section-realtor__form__submit__text"><?php echo __('Send a message', 'linear') ?></span>
                                        <span class="linear-section-realtor__form__submit__loader">
                                            <span><?php echo __('Sending message', 'linear') ?></span>
                                            <span class="linear-section-realtor__form__submit__ellipsis"></span>
                                        </span>
                                        <span class="linear-section-realtor__form__submit__retry"><?php echo __('Something went wrong, try sending the message again', 'linear') ?></span>
                                        <span class="linear-section-realtor__form__submit__finished"><?php echo __('Message sent!', 'linear') ?></span>
                                        <span class="linear-section-realtor__form__submit__error"><?php echo __('Error, something went wrong', 'linear') ?></span>
                                    </button>

                                </form>
                            <?php } ?>

                        </div>

                    <?php do_action('linear_listing_realtor', $listing); ?>
                    <?php do_action('linear_realtor', $listing); ?>

                </div>
            </div>
        </div>

        <?php } else if( $contact_method === '' || $contact_method === 'none' ){
            // do nothing

            ob_start();

            do_action('linear_listing_realtor', $listing);
            do_action('linear_realtor', $listing);

            $hooks_content = ob_get_clean();

            if( $hooks_content && $hooks_content !== '' ){ ?>
                <div class="linear-o-row">
                    <div class="linear-o-col-12">
                        <div class="linear-c-card">
                            <?php echo $hooks_content ?>
                        </div>
                    </div>
                </div>
            <?php }

        } else {
            // and do nothing
        } ?>
        
    <?php return ob_get_clean();
}
